OC.L10N.register(
    "files_sharing",
    {
    "Uploading..." : "កំពុងដាក់បញ្ចូល...",
    "Cancel" : "បោះបង់",
    "Share" : "ចែក​រំលែក",
    "Shared by" : "បាន​ចែក​រំលែក​ដោយ",
    "Sharing" : "ការ​ចែក​រំលែក",
    "A file or folder has been <strong>shared</strong>" : "<strong>បាន​ចែករំលែក</strong> ឯកសារ​ឬ​ថត",
    "You shared %1$s with %2$s" : "អ្នក​បាន​ចែករំលែក %1$s ជាមួយ %2$s",
    "You shared %1$s with group %2$s" : "អ្នក​បាន​ចែករំលែក %1$s ជាមួយ​ក្រុម %2$s",
    "You shared %1$s via link" : "អ្នក​បាន​ចែក​រំលែក %1$s តាម​រយៈ​តំណរភ្ជាប់",
    "%2$s shared %1$s with you" : "%2$s បាន​ចែករំលែក %1$s ជាមួយ​អ្នក",
    "Shares" : "ចែក​រំលែក",
    "This share is password-protected" : "ការ​ចែករំលែក​នេះ​ត្រូវ​បាន​ការពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "The password is wrong. Try again." : "ពាក្យ​សម្ងាត់​ខុស​ហើយ។ ព្យាយាម​ម្ដង​ទៀត។",
    "Password" : "ពាក្យសម្ងាត់",
    "Name" : "ឈ្មោះ",
    "Expiration date" : "ពេល​ផុត​កំណត់",
    "Sorry, this link doesn’t seem to work anymore." : "សូម​ទោស តំណ​នេះ​ហាក់​ដូច​ជា​លែង​ដើរ​ហើយ។",
    "Reasons might be:" : "មូលហេតុ​អាច​ជា៖",
    "the item was removed" : "របស់​ត្រូវ​បាន​ដក​ចេញ",
    "the link expired" : "តំណ​ផុត​ពេល​កំណត់",
    "sharing is disabled" : "មិន​អនុញ្ញាត​ការ​ចែករំលែក",
    "For more info, please ask the person who sent this link." : "សម្រាប់​ព័ត៌មាន​បន្ថែម សូម​សួរ​អ្នក​ដែល​ផ្ញើ​តំណ​នេះ។",
    "Download" : "ទាញយក",
    "Download %s" : "ទាញយក %s",
    "Direct link" : "តំណ​ផ្ទាល់",
    "Pending" : "កំពុង​រង់ចាំ"
},
"nplurals=1; plural=0;");
